//*********************************************************
// This is a modified version of the glfont API by Brad
// Fish
// You can download the original version from:
//
//   E-mail: bfish@netxs.net
//   Web: http://www.netxs.net/bfish
//
// The following modifications are made by Christian Marten
// in order to make this  great toolkit more portable and
// flexible:
//  - GetByte(), GetShort(), GetLong() to get the same
//    results on BigEndian and LittleEndian maschines
//  - glFontCreateASCII() to read an ASCII version of
//    a glFont. The reason for this extention are different
//    binary representations of floats on Intel and MIPS
//    microprocessors.
//  - Use of mipmap in glFontCreateASCII().
//  - glFontConvert() converts the binary version of a glFont
//    to ASCII
//  - glStringSize() returns the width and height of a string
//    in global GL coordinates.
//
//*********************************************************

#ifndef _GLFONT_H_
#define _GLFONT_H_


#ifndef TRUE
#define TRUE	1
#endif

#ifndef FALSE
#define FALSE	0
#endif

//*********************************************************
//Structures
//*********************************************************

//glFont character structure
typedef struct
{
	float dx, dy;
	float tx1, ty1;
	float tx2, ty2;
} GLFONTCHAR;


//glFont structure
typedef struct
{
	int Tex;
	int TexWidth, TexHeight;
	int IntStart, IntEnd;
	GLFONTCHAR *Char;
} GLFONT;


#ifdef OS_WIN32
  void pascal glBindTexture(GLenum target, GLuint texture);
#endif

//*********************************************************
//Function Declarations
//*********************************************************

//Creates a glFont
int glFontCreate (GLFONT *Font, char *FileName, int Tex);
int glFontCreateASCII (GLFONT *Font, char *FileName, int Tex, int useMipmap,
                      int minFilter, int magFilter);
//int glFontCreateASCII (GLFONT *Font, char *FileName, int Tex);

// Converts a font from binary to ascii
int glFontConvert (char *oldFile, char *newFile);

//Deletes a glFont
void glFontDestroy (GLFONT *Font);

//Needs to be called before text output
void glFontBegin (GLFONT *Font);

//Needs to be called after text output
void glFontEnd (void);

//Draws text with a glFont
void glFontTextOut (char *String, float x, float y, float z);

// Retrieves size of a string
void glStringSize (char *String, float *dx, float *dy);

//*********************************************************

//End of file
#endif
